/**
 * SAS Visual Investigator exposes a number of controls within the DOM as Custom Elements.
 *
 * See {@link SVICustomElement} for the list of available SVI Custom Elements.
 */
/**
 * This enumeration list contains the tag names of all SVI custom elements.
 *
 * @category Properties
 */
export var SVICustomElement;
(function (SVICustomElement) {
    /**
     * Wrap a given control in an SVI control label.
     *
     * By default, the label will include a {@link MaskToggleButton | mask-toggle-button}
     * for toggling the masked state of the control's dataSource, if configured for masking.
     *
     * See {@link LabelledControlProperties} for supported input bindings.
     */
    SVICustomElement["LabelledControl"] = "svi-labelled-control";
    /**
     * Toggle a given dataSource between it's masked and unmasked state, if configured for masking.
     *
     * See {@link MaskToggleButtonProperties} for supported input bindings.
     */
    SVICustomElement["MaskToggleButton"] = "svi-mask-toggle-button";
    /**
     * A token input that spawns a dialog for selecting a set of users, a set of groups, or a set of users and groups.
     *
     * See {@link IdentitySelectProperties} for supported input bindings.
     */
    SVICustomElement["IdentitySelect"] = "svi-identity-select";
    /**
     * A button for selecting a set of users, a set of groups, or a set of users and groups.
     *
     * See {@link IdentitySelectActionProperties} for supported input bindings.
     */
    SVICustomElement["IdentitySelectAction"] = "svi-identity-select-action";
    /**
     * An input to select a set of users, a set of groups, or a set of users and groups.
     *
     * See {@link AvatarProperties} for supported input bindings.
     */
    SVICustomElement["Avatar"] = "svi-avatar";
})(SVICustomElement || (SVICustomElement = {}));
export * from "./bindings";
export * from "./identity-select";
export * from "./labelled-control";
export * from "./mask-toggle-button";
