import { PageControlBindings } from ".";
/**
 * Properties for {@link SVICustomElement.MaskToggleButton}.
 *
 * @category Properties
 *
 * @example HTML Example
 * ```html
 * <svi-mask-toggle-button
 *   [childNode]="childNode"
 *   [pageModel]="pageModel"
 * >
 * </svi-mask-toggle-button>
 * ```
 *
 * @example Create element via document.createElement:
 * ```ts
 * const maskToggleBtn = document.createElement(SVICustomElement.MaskToggleButton);
 * maskToggleBtn.pageModel = this.pageModel;
 * maskToggleBtn.childNode = this.childNode;
 * ```
 */
export interface MaskToggleButtonProperties extends PageControlBindings {
    /**
     * Specify which dataSource will be toggled.
     *
     * If no {@link MaskToggleButtonProperties.dataSource | dataSource} is specified,
     * the mask-toggle-button will toggle the dataSource(s) defined in the childNode's typeAttributes.
     */
    dataSource?: string;
    /** Disable the mask toggle button. */
    disabled?: boolean;
    /** Hide the mask toggle button. */
    hidden?: boolean;
    /** Override the control name displayed in the authorization dialog. */
    controlName?: string;
}
